@@ -168,7 +168,6 @@ static void
 gnome_db_error_init (GnomeDbError *error_widget, GnomeDbErrorClass *klass)
 {
 	GtkWidget *table;
-	GtkWidget *detail_table;
 	GtkWidget *label;
 	GtkWidget *scroll;
 	GtkWidget *image;
@@ -219,24 +218,32 @@ gnome_db_error_init (GnomeDbError *error_widget, GnomeDbErrorClass *klass)
 	gtk_container_add (GTK_CONTAINER (scroll), error_widget->priv->error_description);
 
 	/* create the detail container */
-	error_widget->priv->detail_container = gnome_db_new_frame_widget (_("Detail"));
+	error_widget->priv->detail_container = gnome_db_new_table_widget (3, 3, FALSE);
 	gtk_table_attach (GTK_TABLE (table), error_widget->priv->detail_container,
 			  0, 4, 3, 4, GTK_FILL | GTK_SHRINK | GTK_EXPAND,
 			  GTK_FILL | GTK_SHRINK | GTK_EXPAND, 3, 3);
-	detail_table = gnome_db_new_table_widget (2, 3, FALSE);
-	gtk_container_add (GTK_CONTAINER (error_widget->priv->detail_container), detail_table);
+
+	label = gnome_db_new_label_widget (NULL);
+	str = g_strdup_printf ("<b>%s</b>", _("Details"));
+	gtk_label_set_markup (GTK_LABEL (label), str);
+	g_free (str);
+	gtk_table_attach (GTK_TABLE (error_widget->priv->detail_container), label, 0, 3, 0, 1,
+			  GTK_FILL | GTK_EXPAND | GTK_SHRINK,
+			  GTK_FILL, 6, 6);
 
 	label = gnome_db_new_label_widget (_("Source"));
-	gtk_table_attach (GTK_TABLE (detail_table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 3, 3);
+	gtk_table_attach (GTK_TABLE (error_widget->priv->detail_container), label, 1, 2, 1, 2,
+			  GTK_FILL, GTK_FILL, 6, 6);
 	error_widget->priv->error_source = gnome_db_new_entry_widget (0, FALSE);
-	gtk_table_attach (GTK_TABLE (detail_table), error_widget->priv->error_source,
-			  1, 2, 0, 1, GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 3, 3);
+	gtk_table_attach (GTK_TABLE (error_widget->priv->detail_container), error_widget->priv->error_source,
+			  2, 3, 1, 2, GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 6, 6);
 
 	label = gnome_db_new_label_widget (_("SQL state"));
-	gtk_table_attach (GTK_TABLE (detail_table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 3, 3);
+	gtk_table_attach (GTK_TABLE (error_widget->priv->detail_container), label, 1, 2, 2, 3,
+			  GTK_FILL, GTK_FILL, 6, 6);
 	error_widget->priv->error_sqlstate = gnome_db_new_entry_widget (0, FALSE);
-	gtk_table_attach (GTK_TABLE (detail_table), error_widget->priv->error_sqlstate,
-			  1, 2, 1, 2, GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 3, 3);
+	gtk_table_attach (GTK_TABLE (error_widget->priv->detail_container), error_widget->priv->error_sqlstate,
+			  2, 3, 2, 3, GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 6, 6);
 
 	gtk_widget_hide (error_widget->priv->detail_container);
 }
